@@ -367,7 +367,7 @@ class PlotPanel(viewpanel.ViewPanel):
 
         idleName = '{}.draw'.format(id(self))
 
-        if not self.destroyed() and not idle.inIdle(idleName):
+        if not self.destroyed and not idle.inIdle(idleName):
             idle.idle(self.draw, name=idleName)
 
 
@@ -549,9 +549,13 @@ class PlotPanel(viewpanel.ViewPanel):
         else:
             self.__drawQueue.enqueue(idle.idle, realDraw)
 
+        def refreshCanvas():
+            if not self.destroyed:
+                canvas.draw()
+
         if refresh:
-            if immediate: canvas.draw()
-            else:         self.__drawQueue.enqueue(idle.idle, canvas.draw)
+            if immediate: refreshCanvas()
+            else:         self.__drawQueue.enqueue(idle.idle, refreshCanvas)
 
 
     def drawDataSeries(self, extraSeries=None, refresh=False, **plotArgs):
